==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activitates",
    "Error loading activities" : "Error durante le cargamento de activitates",
    "No activities" : "Nulle activitates",
    "Load more activities" : "Incarga altere activitates",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Activity" : "Activitate",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu preferentias ha essite actualisate.",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "\"remote user\"" : "\"usator remote\"",
    "Activity notification" : "Notification de activitate",
    ", " : ",",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Salute %s,",
    "You are receiving this email because the following things happened at %s" : "Tu recipe iste message perque le sequente cosas ha occurrite a %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n altere","* e %n alteres"],
    "List your own actions in the stream" : "Lista tu proprie actiones de file in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "Activity feed" : "Syndication de activitate",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No activity yet" : "Nulle activitate ancora",
    "No more events to load" : "Nulle altere eventos a cargar",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ia.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activitates",
    "An error occurred while loading activities" : "Un error durante le cargamento de activitates",
    "No activity yet" : "Nulle activitate ancora",
    "Load more activities" : "Incarga altere activitates",
    "Copied!" : "Copiate!",
    "Not supported!" : "Non supportate!",
    "Press ⌘-C to copy." : "Pulsa ⌘-C pro copiar.",
    "Press Ctrl-C to copy." : "Pulsa Ctrl-C pro copiar.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (restringite)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Iste fluxo monstra eventos como additiones, cambiamentos e compartimentos",
    "There are no events for this filter" : "Il non ha eventos pro iste filtro",
    "Today" : "Hodie",
    "Yesterday" : "Heri",
    "Personal activity feed for %s" : "Syndication de activitate personal pro %s",
    "Your feed URL is invalid" : "Le URL del syndication es invalide",
    "Your settings have been updated." : "Tu configurationes ha essite actualisate.",
    "Settings have been updated." : "Configurationes actualisate",
    "Mail" : "Posta",
    "Stream" : "Fluxo",
    "All activities" : "Omne activitates",
    "By others" : "Per alteres",
    "By you" : "Per vos",
    "\"remote user\"" : "\"usator remote\"",
    "Hello %s," : "Salute %s,",
    "There was some activity at %s" : "Il habeva alcun activitate in %s",
    "Activity notification" : "Notification de activitate",
    ", " : ",",
    "%s and %s" : "%s e %s",
    "Activity" : "Activitate",
    "Activity feed" : "Syndication de activitate",
    "List your own actions in the stream" : "Lista tu proprie actiones de file in le fluxo",
    "Notify about your own actions via email" : "Notifica super tu proprie actiones via e-posta",
    "You need to set up your email address before you can receive notification emails." : "Tu necessita configurar tu adresse de e-posta ante que tu pote reciper messages de e-posta de notification.",
    "Send emails:" : "Invia messages de e-posta:",
    "Hourly" : "Cata hora",
    "Daily" : "Cata die",
    "Weekly" : "Cata septimana",
    "Settings" : "Configurationes",
    "Enable RSS feed" : "Habilita syndication RSS",
    "No more events to load" : "Nulle altere eventos a cargar",
    "Files" : "Files"
},
"nplurals=2; plural=(n != 1);");
